﻿using System;
using System.IO;
using System.Windows.Forms;

namespace AoDPatcher
{
	public partial class MainForm : Form
	{
		private readonly PatchEngine engine;


		public MainForm()
		{
			engine = new PatchEngine(this);

			InitializeComponent();

			string[] args = Environment.GetCommandLineArgs();
			if (args.Length > 1)
			{
				pathTextBox.Text = args[1];
			}
		}

		private void OnBrowseButtonClick(object sender, EventArgs e)
		{
			OpenFileDialog dialog = new OpenFileDialog();
			if (dialog.ShowDialog() == DialogResult.OK)
			{
				pathTextBox.Text = dialog.FileName;
			}
		}

		private void OnStartButtonClick(object sender, EventArgs e)
		{
			saveButton.Enabled = false;
			if (engine.ExecPatch(pathTextBox.Text))
			{
				saveButton.Enabled = true;
			}
		}

		private void OnSaveButtonClick(object sender, EventArgs e)
		{
			SaveFileDialog dialog = new SaveFileDialog();
			dialog.FileName = "AODGameJp";
			dialog.DefaultExt = "exe";
			dialog.Filter = "実行ファイル (*.exe)|*.exe";
			dialog.InitialDirectory = Path.GetDirectoryName(pathTextBox.Text);
			if (dialog.ShowDialog() == DialogResult.OK)
			{
				engine.SavePatchedFile(dialog.FileName);
			}
		}

		private void OnExitButtonClick(object sender, EventArgs e)
		{
			Application.Exit();
		}

		public void AppendLog(string s)
		{
			logRichTextBox.AppendText(s);
		}

		private void OnPathTextBoxDragDrop(object sender, DragEventArgs e)
		{
			string[] fileNames = (string[])e.Data.GetData(DataFormats.FileDrop, false);
			pathTextBox.Text = fileNames[0];
		}

		private void OnPathTextBoxDragEnter(object sender, DragEventArgs e)
		{
			if ((e.Data.GetDataPresent(DataFormats.FileDrop)))
			{
				e.Effect = DragDropEffects.Copy;
			}
			else
			{
				e.Effect = DragDropEffects.None;
			}
		}
	}
}