﻿using System.IO;
using System.Text;

namespace AoDRenamer
{
	internal class AoDRenamerEngine
	{
		private readonly MainForm mainForm;

		private string baseFolderName;

		public AoDRenamerEngine(MainForm mainForm)
		{
			this.mainForm = mainForm;
		}

		public void Start(string folderName)
		{
			baseFolderName = folderName;

			RenameFiles();
		}

		private void RenameFiles()
		{
			StreamReader sr = new StreamReader("rename.ini", Encoding.Default);
			string line;
			char[] separator = new char[] {','};
			while ((line = sr.ReadLine()) != null)
			{
				if (string.IsNullOrEmpty(line))
				{
					LogWrite("\n");
					continue;
				}
				if (line[0] == '#')
				{
					LogWrite(string.Format("{0}\n", line));
					continue;
				}
				string[] token = line.Split(separator);
				if (token.Length >= 2)
				{
					RenameFile(token[0], token[1]);
				}
			}
		}

		private void RenameFile(string originalFileName, string targetFileName)
		{
			string originalPathName = Path.Combine(baseFolderName, originalFileName);
			string targetPathName = Path.Combine(baseFolderName, targetFileName);
			// 変更元のファイルがなければスキップ
			if (!File.Exists(originalPathName))
			{
				LogWrite(string.Format("SKIP  : {0}\n", originalFileName));
				return;
			}
			// 変更先にファイルがある場合
			if (File.Exists(targetPathName))
			{
				// 変更先のファイルの方が古ければ上書き
				if (File.GetLastWriteTime(targetPathName) < File.GetLastWriteTime(originalPathName))
				{
					File.Delete(targetPathName);
					File.Move(originalPathName, targetPathName);
					LogWrite(string.Format("OVRWRT: {0} => {1}\n", originalFileName, targetFileName));
				}
				// 変更先のファイルの方が新しいか同じならば削除
				else
				{
					File.Delete(originalPathName);
					LogWrite(string.Format("DELETE: {0}\n", originalFileName));
				}
				return;
			}
			// 変更先にファイルがなければリネーム
			File.Move(originalPathName, targetPathName);
			LogWrite(string.Format("RENAME: {0} => {1}\n", originalFileName, targetFileName));
		}

		private void LogWrite(string s)
		{
			mainForm.AppendLog(s);
		}
	}
}