﻿using System;
using System.IO;
using System.Windows.Forms;

namespace AoDRenamer
{
	public partial class MainForm : Form
	{
		private readonly AoDRenamerEngine engine;

		public MainForm()
		{
			engine = new AoDRenamerEngine(this);

			InitializeComponent();

			string[] args = Environment.GetCommandLineArgs();
			if (args.Length > 1)
			{
				folderNameTextBox.Text = args[1];
			}
		}

		private void OnReferenceButtonClick(object sender, EventArgs e)
		{
			FolderBrowserDialog dialog = new FolderBrowserDialog();
			if (dialog.ShowDialog() == DialogResult.OK)
			{
				folderNameTextBox.Text = dialog.SelectedPath;
			}
		}

		private void OnStartButtonClick(object sender, EventArgs e)
		{
			if (string.IsNullOrEmpty(folderNameTextBox.Text) || !Directory.Exists(folderNameTextBox.Text))
			{
				MessageBox.Show("AoD/gfx/interface/picsのフォルダ名を指定して下さい。");
				return;
			}

			if (!File.Exists("rename.ini"))
			{
				MessageBox.Show("rename.iniが見つかりません。");
				return;
			}

			engine.Start(folderNameTextBox.Text);
		}

		private void OnExitButtonClick(object sender, EventArgs e)
		{
			Application.Exit();
		}

		public void AppendLog(string s)
		{
			logRichTextBox.AppendText(s);
		}

		private void OnFolderNameTextBoxDragDrop(object sender, DragEventArgs e)
		{
			string[] fileNames = (string[]) e.Data.GetData(DataFormats.FileDrop, false);
			folderNameTextBox.Text = fileNames[0];
		}

		private void OnFolderNameTextBoxDragEnter(object sender, DragEventArgs e)
		{
			e.Effect = (e.Data.GetDataPresent(DataFormats.FileDrop)) ? DragDropEffects.Copy : DragDropEffects.None;
		}
	}
}